==> holado-0.13.8.tar.gz: holado-0.13.8/src/holado_tools/tools/host_controller/server/rest/api/docker/logs.py <==
#################################################
# HolAdo (Holistic Automation do)
#
# (C) Copyright 2021-2025 by Eric Klumpp
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the “Software”), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

# The Software is provided “as is”, without warranty of any kind, express or implied, including but not limited to the warranties of merchantability, fitness for a particular purpose and noninfringement. In no event shall the authors or copyright holders be liable for any claim, damages or other liability, whether in an action of contract, tort or otherwise, arising from, out of or in connection with the software or the use or other dealings in the Software.
#################################################

from flask.views import MethodView
from holado.common.context.session_context import SessionContext
from holado_docker.sdk.docker.container_logs import DockerContainersLogsSaver

def _get_session_context():
    return SessionContext.instance()


class SaveView(MethodView):
    
    def put(self, body: dict):
        destination_path = body['destination_path']
        include_patterns = body.get('include_patterns', [])
        exclude_patterns = body.get('exclude_patterns', [])
        with_timestamps = body.get('with_timestamps', True)
        since = body.get('since', None)
        until = body.get('until', None)
        
        saver = DockerContainersLogsSaver(_get_session_context().docker_client, 
                                          include_patterns=include_patterns,
                                          exclude_patterns=exclude_patterns)
        res = saver.save_containers_logs(destination_path, timestamps=with_timestamps, since=since, until=until)
        
        return res

==> holado-0.13.9.tar.gz: holado-0.13.9/src/holado_tools/tools/host_controller/server/rest/api/docker/logs.py <==
#################################################
# HolAdo (Holistic Automation do)
#
# (C) Copyright 2021-2025 by Eric Klumpp
# 
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the “Software”), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
# 
# The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

# The Software is provided “as is”, without warranty of any kind, express or implied, including but not limited to the warranties of merchantability, fitness for a particular purpose and noninfringement. In no event shall the authors or copyright holders be liable for any claim, damages or other liability, whether in an action of contract, tort or otherwise, arising from, out of or in connection with the software or the use or other dealings in the Software.
#################################################

from flask.views import MethodView
from holado.common.context.session_context import SessionContext
from holado_docker.sdk.docker.container_logs import DockerContainersLogsSaver
import logging


logger = logging.getLogger(__name__)


def _get_session_context():
    return SessionContext.instance()


class SaveView(MethodView):
    
    def put(self, body: dict):
        try:
            destination_path = body['destination_path']
            include_patterns = body.get('include_patterns', [])
            exclude_patterns = body.get('exclude_patterns', [])
            with_timestamps = body.get('with_timestamps', True)
            since = body.get('since', None)
            until = body.get('until', None)
            
            saver = DockerContainersLogsSaver(_get_session_context().docker_client, 
                                              include_patterns=include_patterns,
                                              exclude_patterns=exclude_patterns)
            res = saver.save_containers_logs(destination_path, timestamps=with_timestamps, since=since, until=until)
            
            return res
        except Exception as exc:
            logger.exception(f"Failed to save logs (parameters: {body})")
            return str(exc), 500
